@@ -6,6 +6,7 @@ import time
 from abc import ABC
 from collections import defaultdict
 from typing import Any
+from warnings import warn
 
 import aiohttp
 from requests.exceptions import ReadTimeout
@@ -22,6 +23,8 @@ from pyatmo.const import (
 from pyatmo.exceptions import ApiError, NoDevice
 from pyatmo.helpers import LOG, extract_raw_data
 
+warn(f"The module {__name__} is deprecated.", DeprecationWarning, stacklevel=2)
+
 
 class AbstractCameraData(ABC):
     """Abstract class of Netatmo camera data."""
@@ -661,7 +664,7 @@ class AsyncCameraData(AbstractCameraData):
 
         try:
             await self._async_update_all_camera_urls()
-        except aiohttp.ContentTypeError as err:
+        except (aiohttp.ContentTypeError, aiohttp.ClientConnectorError) as err:
             LOG.debug("One or more camera could not be reached. (%s)", err)
 
         self._store_last_event()
@@ -788,10 +791,7 @@ class AsyncCameraData(AbstractCameraData):
             timeout=10,
         )
 
-        if not isinstance(resp, bytes):
-            return None
-
-        return resp
+        return resp if isinstance(resp, bytes) else None
 
     async def async_get_camera_picture(
         self,
@@ -805,10 +805,11 @@ class AsyncCameraData(AbstractCameraData):
             params=post_params,
         )
 
-        if not isinstance(resp, bytes):
-            return b"", None
-
-        return resp, imghdr.what("NONE.FILE", resp)
+        return (
+            (resp, imghdr.what("NONE.FILE", resp))
+            if isinstance(resp, bytes)
+            else (b"", None)
+        )
 
     async def async_get_profile_image(
         self,
